@@ -26,7 +26,7 @@ import argcomplete
 import colorama
 from appdirs import user_config_dir
 
-from .ansi import ANSIEmojiLoglevelFormatter, ANSIStrippingEmojiLoglevelFormatter, ANSIStrippingFormatter, ansi_colors, ansi_escape, format_ansi
+from .ansi import MILCFormatter, ansi_colors, ansi_config, ansi_escape, format_ansi
 from .configuration import Configuration, SubparserWrapper, get_argument_name, handle_store_boolean
 from .attrdict import AttrDict
 
@@ -34,11 +34,8 @@ from .attrdict import AttrDict
 class MILC(object):
     """MILC - An Opinionated Batteries Included Framework
     """
-    def __init__(self, version='unknown'):
+    def __init__(self):
         """Initialize the MILC object.
-
-            version
-                The version string to associate with your CLI program
         """
         # Setup a lock for thread safety
         self._lock = threading.RLock() if thread else None
@@ -55,7 +52,6 @@ class MILC(object):
         self.config = self.config_source = None
         self.config_file = None
         self.default_arguments = {}
-        self.version = version
         self.platform = platform()
 
         # Figure out our program name
@@ -178,20 +174,25 @@ class MILC(object):
 
         return self._arg_parser.print_usage(*args, **kwargs)
 
-    def completer(self, completer):
-        """Add an argcomplete completer to this subcommand.
-        """
-        self._arg_parser.completer = completer
-
     def add_argument(self, *args, **kwargs):
         """Wrapper to add arguments and track whether they were passed on the command line.
         """
         if 'action' in kwargs and kwargs['action'] == 'store_boolean':
             return handle_store_boolean(self, *args, **kwargs)
 
+        completer = None
+
+        if kwargs.get('completer'):
+            completer = kwargs['completer']
+            del(kwargs['completer'])
+
         self.acquire_lock()
 
-        self._arg_parser.add_argument(*args, **kwargs)
+        if completer:
+            self._arg_parser.add_argument(*args, **kwargs).completer = completer
+        else:
+            self._arg_parser.add_argument(*args, **kwargs)
+
         if 'general' not in self.default_arguments:
             self.default_arguments['general'] = {}
         self.default_arguments['general'][get_argument_name(self, *args, **kwargs)] = kwargs.get('default')
@@ -215,14 +216,15 @@ class MILC(object):
         logging.root.setLevel(logging.DEBUG)
         self.release_lock()
 
-        self.add_argument('-V', '--version', version=self.version, action='version', help='Display the version and exit')
+        self.add_argument('-V', '--version', version=os.environ.get('MILC_APP_VERSION', 'unknown'), action='version', help='Display the version and exit')
         self.add_argument('-v', '--verbose', action='store_true', help='Make the logging more verbose')
         self.add_argument('--datetime-fmt', default='%Y-%m-%d %H:%M:%S', help='Format string for datetimes')
         self.add_argument('--log-fmt', default='%(levelname)s %(message)s', help='Format string for printed log output')
         self.add_argument('--log-file-fmt', default='[%(levelname)s] [%(asctime)s] [file:%(pathname)s] [line:%(lineno)d] %(message)s', help='Format string for log file.')
         self.add_argument('--log-file-level', default='info', choices=['debug', 'info', 'warning', 'error', 'critical'], help='Logging level for log file.')
         self.add_argument('--log-file', help='File to write log messages to')
-        self.add_argument('--color', action='store_boolean', default=True, help='color in output')
+        self.add_argument('--color', action='store_boolean', default=ansi_config['color'], help='color in output')
+        self.add_argument('--unicode', action='store_boolean', default=ansi_config['unicode'], help='unicode loglevels')
         self.add_argument('--config-file', help='The location for the configuration file')
         self.arg_only['config_file'] = ['general']
 
@@ -249,15 +251,13 @@ class MILC(object):
     def find_config_file(self):
         """Locate the config file.
         """
-        if self.config_file:
-            return self.config_file
-
         if '--config-file' in sys.argv:
             return Path(sys.argv[sys.argv.index('--config-file') + 1]).expanduser().resolve()
 
         filedir = user_config_dir(appname=self.prog_name, appauthor=os.environ.get('MILC_APP_AUTHOR', self.prog_name.upper()))
         filename = '%s.ini' % self.prog_name
-        return Path(filedir) / filename
+
+        return Path(filedir, filename).resolve()
 
     def argument(self, *args, **kwargs):
         """Decorator to call self.add_argument or self.<subcommand>.add_argument.
@@ -551,14 +551,13 @@ class MILC(object):
         if self.config.general.verbose:
             self.log_print_level = logging.DEBUG
 
-        self.log_file = self.config.general.log_file or self.log_file
-        self.log_file_format = ANSIStrippingFormatter(self.config.general.log_file_fmt, self.config.general.datetime_fmt)
-        self.log_file_level = getattr(logging, self.config.general.log_file_level.upper())
+        ansi_config['color'] = self.config.general.color
+        ansi_config['unicode'] = self.config.general.unicode
 
-        if self.config.general.color:
-            self.log_format = ANSIEmojiLoglevelFormatter(self.config.general.log_fmt, self.config.general.datetime_fmt)
-        else:
-            self.log_format = ANSIStrippingEmojiLoglevelFormatter(self.config.general.log_fmt, self.config.general.datetime_fmt)
+        self.log_file = self.config.general.log_file or self.log_file
+        self.log_file_format = MILCFormatter(self.config.general.log_file_fmt, self.config.general.datetime_fmt)
+        self.log_file_level = getattr(logging, self.config.general.log_file_level.upper())
+        self.log_format = MILCFormatter(self.config.general.log_fmt, self.config.general.datetime_fmt)
 
         if self.log_file:
             self.log_file_handler = logging.FileHandler(self.log_file, self.log_file_mode)
